FAQ — Django Grappelli 2.4.8 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.4.8 documentation »

# FAQ

Some questions, some answers.

## Why should I use Grappelli?

If you are pleased with how the original admin interface looks, you shouldn’t.

## I need help!

see Troubleshooting.

## Which Browser do I need with Grappelli?

We are testing with Firefox, Chrome and Safari. IE9 and Opera should work fine as well.

## Can I use another editor than TinyMCE?

Of course.

## Why are you using TinyMCE and not RedactorJS?

Unfortunately, Redactor currently produces strange/wrong HTML. Moreover, we’re missing an easy way to define formatting–options as well as a possibility to insert classes. That being said, TinyMCE will be removed with version 2.5 of Grappelli. Instead, we will add a skin for TinyMCE.

## Why don’t you use Twitter Bootstrap?

For now, custom Compass-based stylesheets gives us much more options. But we do understand the need to easily customize the admin interface and we’re discussing this issue on a regular basis.

## Do you guys cooperate with the Django–Devs?

Occasionally, we discuss features and implementations.

## How can I contribute?

Help is very much appreciated.

- Fork django-grappelli and submit feedback/patches.
- Work on Django Tickets related to contrib.admin.
- Take a look at Django Issues.

## What is your goal with Grappelli?

Our goal is that Grappelli will be redundant eventually (though we doubt that will happen).

## Who develops Grappelli?

Grappelli is developed and maintained by Patrick Kranzlmüller & Axel Swoboda of vonautomatisch.

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.4.8 documentation »